changeset 86:2d9624e04134

Fix bottom padding and scrollbar color
author nanaya <me@nanaya.pro>
date Mon, 13 Sep 2021 18:14:08 +0900
parents 9c8cde985caf
children dac3ba0cd960
files tweetdeck-column-fix.user.js
diffstat 1 files changed, 6 insertions(+), 2 deletions(-) [+]
line wrap: on
line diff
--- a/tweetdeck-column-fix.user.js	Thu Apr 15 15:01:22 2021 +0900
+++ b/tweetdeck-column-fix.user.js	Mon Sep 13 18:14:08 2021 +0900
@@ -1,8 +1,8 @@
 // ==UserScript==
 // @name         Tweetdeck column fix
 // @namespace    https://myconan.net
 // @version      1.0.2
 // @description  No weird column alignment
 // @author       nanaya
 // @match        https://tweetdeck.twitter.com/*
 // @grant        GM_addStyle
@@ -18,4 +18,8 @@
     top: 0;
     flex: none;
   }
+  .app-columns-container.app-columns-container.app-columns-container.app-columns-container {
+    bottom: 0;
+    background-color: #555;
+  }
 `)
@@ -1,8 +1,8 @@
 // @name         Tweetdeck column fix
 // @namespace    https://myconan.net
-// @version      1.0.2
-// @description  No weird column alignment
+// @version      1.1.0
+// @description  No weird column alignment and color for scrollbar
 // @author       nanaya
 // @match        https://tweetdeck.twitter.com/*